@@ -29,6 +29,7 @@ G_BEGIN_DECLS
 
 const char *	rb_file			(const char *filename);
 const char *	rb_dot_dir		(void);
+const char *	rb_music_dir		(void);
 
 char *		rb_canonicalise_uri	(const char *uri);
 
@@ -42,13 +43,25 @@ char *		rb_uri_resolve_relative	(const char *uri);
 gboolean	rb_uri_is_readable	(const char *uri);
 gboolean	rb_uri_is_writable	(const char *uri);
 gboolean	rb_uri_is_local		(const char *uri);
+gboolean	rb_uri_is_hidden	(const char *uri);
+char *		rb_uri_make_hidden      (const char *uri);
 char *		rb_uri_get_dir_name	(const char *uri);
+char *		rb_uri_get_short_path_name (const char *uri);
+
+/* return TRUE to recurse further, FALSE to stop */
+typedef gboolean (*RBUriRecurseFunc) (const char *uri, gboolean dir, gpointer data);
 
 void		rb_uri_handle_recursively(const char *uri,
-					  GFunc func,
+					  RBUriRecurseFunc func,
 					  gboolean *cancelflag,
 					  gpointer user_data);
 
+void		rb_uri_handle_recursively_async(const char *uri,
+						RBUriRecurseFunc func,
+						gboolean *cancelflag,
+						gpointer user_data,
+						GDestroyNotify data_destroy);
+
 char*		rb_uri_append_path	(const char *uri,
 					 const char *path);
 char*		rb_uri_append_uri	(const char *uri,
